/*****************************************************************************
/*
/*            INSTITUTO NACIONAL PARA LA EVALUACIN DE LA EDUCACIN
/*             UNIDAD DE EVALUACIN DEL SISTEMA EDUCATIVO NACIONAL
/*             DIRECCIN GENERAL DE MEDICIN Y TRATAMIENTO DE DATOS
/*
/*                      DIRECCIN DE TRATAMIENTO DE DATOS
/*
/*_____________________________________________________________________________
/*
/*            EXAMENES DE LA CALIDAD Y EL LOGRO EDUCATIVOS (Excale)
/*                     SEXTO GRADO DE PRIMARIA (Excale 06)
/*
/*                              **** ESCUELAS ****
/*
/*                     Ciclo escolar evaluado: 2012 - 2013
/*_____________________________________________________________________________
/*
/*
/*        SINTAXIS PARA CONSTRUIR LA BASE DE DATOS DE ALUMNOS DE ESCUELAS
/*                                  EN FORMATO SAS
/*_____________________________________________________________________________
/*
/*  El programa convierte al archivo Excale06_2013_Escuelas.txt, el cual est en
/*  formato ASCII, en una base de datos en formato SAS. El programa realiza las
/*  siguientes tareas:
/*   - Declara formatos para algunas variables
/*   - Lee las variables del archivo en formato ASCII
/*   - Declara los valores considerados en el anlisis como perdidos (missing values)
/*
/* INSTRUCCIONES
/*  Para construir la base de datos (tabla de datos) es necesario:
/*      1) Crear una carpeta de trabajo y colocar en ella al archivo Excale06_2013_Escuelas.txt
/*         as como el archivo Excale06_2013_Escuelas.SAS (este archivo) los cules se pueden
/*         descargar del sitio web del INEE (www.inee.edu.mx).
/*      2) Modificar la primera y segunda lnea de los comandos de este archivo
/*         (libname y filename) para actualizar el nombre de la librera y el archivo
/*         de trabajo.
/*      3) Ejecutar el programa del archivo.
/*
/*  Al finalizar, se deber contar con la base de datos (tabla de datos) Excale06_2013_Escuelas.sas7bdat
/*
/*  Posteriormente, cuando se desee utilizar nuevamente la base Excale06_2013_Escuelas.sas7bdat,
/*  se deber ejecutar primero el procedimiento FORMAT ("proc FORMAT") de este programa para que
/*  SAS cargue los formatos necesarios para abrir la base.
/*
/* CONTACTO:
/*
/*      Para mayor informacin o aclaracin de dudas favor de contactar a la
/*      Direccin de Tratamiento de Datos
/*      Correo electrnico: excale.analisis@inee.edu.mx
/*      Tel 5482 0900 Ext. 32025
/*      Domicilio: Av. Barranca del Muerto no. 341, 3er piso. Col. San Jos Insurgentes
/*                 Del. Benito Jurez. Mxico. D.F.
/*
/* FECHA DE LIBERACIN: 12 DE DICIEMBRE DEL 2014
/*
/*  ****************************************************************************/


LIBNAME  INEE  "C:\***\";
FILENAME esc   "C:\***\Excale06_2013_Escuelas.TXT";

PROC FORMAT;
     VALUE id_entF     1         = "Aguascalientes"
                       2         = "Baja California"
                       3         = "Baja California Sur"
                       4         = "Campeche"
                       5         = "Coahuila"
                       6         = "Colima"
                       7         = "Chiapas"
                       8         = "Chihuahua"
                       9         = "Distrito Federal"
                       10        = "Durango"
                       11        = "Guanajuato"
                       12        = "Guerrero"
                       13        = "Hidalgo"
                       14        = "Jalisco"
                       15        = "Mxico"
                       16        = "Michoacn"
                       17        = "Morelos"
                       18        = "Nayarit"
                       19        = "Nuevo Len"
                       20        = "Oaxaca"
                       21        = "Puebla"
                       22        = "Quertaro"
                       23        = "Quintana Roo"
                       24        = "San Luis Potos"
                       25        = "Sinaloa"
                       26        = "Sonora"
                       27        = "Tabasco"
                       28        = "Tamaulipas"
                       29        = "Tlaxcala"
                       30        = "Veracruz"
                       31        = "Yucatn"
                       32        = "Zacatecas";
     VALUE id_turnF    1         = "Matutino"
                       2         = "Vespertino"
                       3         = "Nocturno"
                       4         = "Discontinuo"
                       5         = "Mixto"
                       6         = "Complementario";
     VALUE id_modF     1         = "Urbana Pblica"
                       2         = "Rural Pblica"
                       3         = "Educacin Indgena"
                       4         = "Curso Comunitario"
                       5         = "Primaria privada"
                       6         = "General"
                       7         = "Tcnica"
                       8         = "Telesecundaria"
                       9         = "Secundaria privada";
     VALUE $modF       "UP"      = "Urbano Pblico"
                       "RP"      = "Rural Pblico"
                       "EI"      = "Educacin Indgena"
                       "CC"      = "Cursos Comunitarios"
                       "UPV"     = "Privados"
                       "GRAL"    = "General"
                       "TEC"     = "Tcnica"
                       "TV"      = "Telesecundaria"
                       "PRIV"    = "Privada";
     VALUE $entestF    "999"     ="Respuesta omitida";
RUN;



DATA INEE.Excale06_2013_Escuelas;
   LENGTH
       PROYECTO           $6
       ANIO               4
       ESCUELA            5
       ID_ENT             3
       NOM_ENT            $19
       ID_TURNO           3
       TURNO_ESC          $18
       ID_MOD             3
       MOD                $4
       ENTEST             $6
       ALU_ESC            3
       ALU_SHI            3
       ESC_UH             4
  ;

 INFILE esc MISSOVER LINESIZE = 75;
   INPUT
       PROYECTO          1 - 6
       ANIO              7 - 10
       ESCUELA          11 - 15
       ID_ENT           16 - 17
       NOM_ENT          18 - 36
       ID_TURNO         37 - 37
       TURNO_ESC        38 - 55
       ID_MOD           56 - 56
       MOD              57 - 60
       ENTEST           61 - 66
       ALU_ESC          67 - 69
       ALU_SHI          70 - 71
       ESC_UH           72 - 75
   ;

 LABEL
       PROYECTO    = "Proyecto al que pertenece el estudio"
       ANIO        = "Ao del levantamiento de datos"
       ESCUELA     = "Identificador de la escuela"
       ID_ENT      = "Entidad federativa (identificador numrico)"
       NOM_ENT     = "Entidad federativa"
       ID_TURNO    = "Turno de la escuela (numrico)"
       TURNO_ESC   = "Turno de la escuela"
       ID_MOD      = "Estrato escolar o Modalidad educativa (identificador numrico)"
       MOD         = "Estrato escolar o Modalidad educativa"
       ENTEST      = "Estratos del diseo muestral con el que se estiman los parmetros y errores estndar (Entidad federativa-Modalidad)"
       ALU_ESC     = "Cantidad de alumnos de 6o de primaria en la escuela"
       ALU_SHI     = "Cantidad de alumnos evaluados en la escuela"
       ESC_UH      = "Cantidad de escuelas en el estrato muestral ENTEST"
   ;

   FORMAT
       ID_ENT            id_entF.
       ID_TURNO          id_turnF.
       ID_MOD            id_modF.
       MOD               $modF.
       ENTEST            $entestF.
   ;




/**************************************************************************
/*  Definicin de valores perdidos
/*   .N o N = No Administrado o no alcanzado.
/*   .M o M = Respuesta Mltiple.
/*   .S o S = Respuesta omitida (No contestado).
/*************************************************************************/

   IF  entest = "999" THEN  entest = .S;




RUN;



